@@ -19,7 +19,6 @@ def test_sphere():
     assert abs(max(mesh.points[:, 2]) - radius) < tol
     assert abs(min(mesh.points[:, 2]) + radius) < tol
 
-    areas = helpers.compute_triangle_areas(mesh.points, mesh.cells["triangle"])
+    areas = helpers.compute_triangle_areas(mesh.points, mesh.get_cells_type("triangle"))
     surface_area = sum(areas)
     assert abs(surface_area - 4 * numpy.pi * radius ** 2) < 0.1
-    return
