@@ -15,9 +15,8 @@ def test_ball():
     assert abs(max(mesh.points[:, 2]) - 1.0) < 0.02
     assert abs(min(mesh.points[:, 2]) + 1.0) < 0.02
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 4.0 / 3.0 * numpy.pi) < 0.15
-    return
 
 
 def test_balls_union():
@@ -47,7 +46,7 @@ def test_balls_union():
     assert abs(max(mesh.points[:, 2]) - radius) < 0.02
     assert abs(min(mesh.points[:, 2]) + radius) < 0.02
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     h = radius - displacement
     ref_vol = 2 * (
         4.0 / 3.0 * numpy.pi * radius ** 3 - h * numpy.pi / 6.0 * (3 * a ** 2 + h ** 2)
@@ -55,8 +54,6 @@ def test_balls_union():
 
     assert abs(vol - ref_vol) < 0.1
 
-    return
-
 
 def test_balls_intersection():
     radius = 1.0
@@ -85,14 +82,12 @@ def test_balls_intersection():
     assert abs(max(mesh.points[:, 2]) - a) < 0.02
     assert abs(min(mesh.points[:, 2]) + a) < 0.02
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     h = radius - displacement
     ref_vol = 2 * (h * numpy.pi / 6.0 * (3 * a ** 2 + h ** 2))
 
     assert abs(vol - ref_vol) < 0.1
 
-    return
-
 
 def test_balls_difference():
     radius = 1.0
@@ -129,7 +124,7 @@ def test_balls_difference():
     assert abs(max(mesh.points[:, 2]) - radius) < tol
     assert abs(min(mesh.points[:, 2]) + radius) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     h = radius - displacement
     ref_vol = 4.0 / 3.0 * numpy.pi * radius ** 3 - 2 * h * numpy.pi / 6.0 * (
         3 * a ** 2 + h ** 2
@@ -137,8 +132,6 @@ def test_balls_difference():
 
     assert abs(vol - ref_vol) < 0.05
 
-    return
-
 
 def test_cuboids_intersection():
     c0 = pygalmesh.Cuboid([0, 0, -0.5], [3, 3, 0.5])
@@ -159,7 +152,7 @@ def test_cuboids_intersection():
     mesh = pygalmesh.generate_mesh(u, cell_size=0.1, edge_size=0.1, verbose=False)
 
     # filter the vertices that belong to cells
-    verts = mesh.points[numpy.unique(mesh.cells["tetra"])]
+    verts = mesh.points[numpy.unique(mesh.get_cells_type("tetra"))]
 
     tol = 1.0e-2
     assert abs(max(verts[:, 0]) - 2.0) < tol
@@ -169,11 +162,9 @@ def test_cuboids_intersection():
     assert abs(max(verts[:, 2]) - 0.5) < 0.05
     assert abs(min(verts[:, 2]) + 0.5) < 0.05
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 1.0) < 0.05
 
-    return
-
 
 def test_cuboids_union():
     c0 = pygalmesh.Cuboid([0, 0, -0.5], [3, 3, 0.5])
@@ -183,7 +174,7 @@ def test_cuboids_union():
     mesh = pygalmesh.generate_mesh(u, cell_size=0.2, edge_size=0.2, verbose=False)
 
     # filter the vertices that belong to cells
-    verts = mesh.points[numpy.unique(mesh.cells["tetra"])]
+    verts = mesh.points[numpy.unique(mesh.get_cells_type("tetra"))]
 
     tol = 1.0e-2
     assert abs(max(verts[:, 0]) - 3.0) < tol
@@ -193,9 +184,8 @@ def test_cuboids_union():
     assert abs(max(verts[:, 2]) - 2.0) < tol
     assert abs(min(verts[:, 2]) + 2.0) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 12.0) < 0.1
-    return
 
 
 def test_cuboid():
@@ -210,9 +200,8 @@ def test_cuboid():
     assert abs(max(mesh.points[:, 2]) - 3.0) < tol
     assert abs(min(mesh.points[:, 2]) + 0.0) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 6.0) < tol
-    return
 
 
 def test_cone():
@@ -232,10 +221,9 @@ def test_cone():
     assert abs(max(mesh.points[:, 2]) - height) < tol
     assert abs(min(mesh.points[:, 2]) + 0.0) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     ref_vol = numpy.pi * base_radius * base_radius / 3.0 * height
     assert abs(vol - ref_vol) < tol
-    return
 
 
 def test_cylinder():
@@ -256,10 +244,9 @@ def test_cylinder():
     assert abs(max(mesh.points[:, 2]) - z1) < tol
     assert abs(min(mesh.points[:, 2]) + z0) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     ref_vol = numpy.pi * radius * radius * (z1 - z0)
     assert abs(vol - ref_vol) < tol
-    return
 
 
 def test_tetrahedron():
@@ -276,9 +263,8 @@ def test_tetrahedron():
     assert abs(max(mesh.points[:, 2]) - 1.0) < tol
     assert abs(min(mesh.points[:, 2]) + 0.0) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 1.0 / 6.0) < tol
-    return
 
 
 def test_torus():
@@ -296,21 +282,19 @@ def test_torus():
     assert abs(max(mesh.points[:, 2]) - minor_radius) < tol
     assert abs(min(mesh.points[:, 2]) + minor_radius) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     ref_vol = (numpy.pi * minor_radius * minor_radius) * (2 * numpy.pi * major_radius)
     assert abs(vol - ref_vol) < 1.0e-1
-    return
 
 
 def test_custom_function():
     class Hyperboloid(pygalmesh.DomainBase):
         def __init__(self, edge_size):
-            super(Hyperboloid, self).__init__()
+            super().__init__()
             self.z0 = -1.0
             self.z1 = 1.0
             self.waist_radius = 0.5
             self.edge_size = edge_size
-            return
 
         def eval(self, x):
             if self.z0 < x[2] and x[2] < self.z1:
@@ -362,9 +346,8 @@ def test_custom_function():
     assert abs(max(mesh.points[:, 2]) - 1.0) < tol
     assert abs(min(mesh.points[:, 2]) + 1.0) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 2 * numpy.pi * 47.0 / 60.0) < 0.16
-    return
 
 
 def test_scaling():
@@ -380,9 +363,8 @@ def test_scaling():
     assert abs(max(mesh.points[:, 2]) - 3 * alpha) < tol
     assert abs(min(mesh.points[:, 2]) + 0.0) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 6.0 * alpha ** 3) < tol
-    return
 
 
 def test_stretch():
@@ -398,11 +380,9 @@ def test_stretch():
     assert abs(max(mesh.points[:, 2]) - 3.0) < tol
     assert abs(min(mesh.points[:, 2]) + 0.0) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 12.0) < tol
 
-    return
-
 
 def test_rotation():
     s0 = pygalmesh.Rotate(
@@ -411,9 +391,8 @@ def test_rotation():
     mesh = pygalmesh.generate_mesh(s0, cell_size=0.1, edge_size=0.1, verbose=False)
 
     tol = 1.0e-2
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 6.0) < tol
-    return
 
 
 def test_translation():
@@ -427,9 +406,8 @@ def test_translation():
     assert abs(min(mesh.points[:, 1]) + 0.0) < tol
     assert abs(max(mesh.points[:, 2]) - 3.0) < tol
     assert abs(min(mesh.points[:, 2]) + 0.0) < tol
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 6.0) < tol
-    return
 
 
 def test_extrude():
@@ -446,9 +424,8 @@ def test_extrude():
     assert abs(max(mesh.points[:, 2]) - 1.0) < 1.1e-3
     assert abs(min(mesh.points[:, 2]) + 0.0) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 0.4) < tol
-    return
 
 
 def test_extrude_rotate():
@@ -467,9 +444,8 @@ def test_extrude_rotate():
     assert abs(max(mesh.points[:, 2]) - 1.0) < tol
     assert abs(min(mesh.points[:, 2]) + 0.0) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 0.4) < 0.05
-    return
 
 
 def test_ring_extrude():
@@ -488,16 +464,14 @@ def test_ring_extrude():
     assert abs(max(mesh.points[:, 2]) - 0.5) < tol
     assert abs(min(mesh.points[:, 2]) + 0.3) < tol
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 2 * numpy.pi * 0.4) < 0.05
-    return
 
 
 def test_heart():
     class Heart(pygalmesh.DomainBase):
         def __init__(self, edge_size):
-            super(Heart, self).__init__()
-            return
+            super().__init__()
 
         def eval(self, x):
             return (
@@ -521,10 +495,9 @@ def test_heart():
         # verbose=True
     )
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     ref = 3.3180194961823872
     assert abs(vol - ref) < 1.0e-3 * ref
-    return
 
 
 def test_halfspace():
@@ -534,9 +507,8 @@ def test_halfspace():
 
     mesh = pygalmesh.generate_mesh(u, cell_size=0.2, edge_size=0.2, verbose=False)
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 1 / 750) < 1.0e-3
-    return
 
 
 def test_ball_with_sizing_field():
@@ -561,9 +533,8 @@ def test_ball_with_sizing_field():
     assert abs(max(mesh.points[:, 2]) - 1.0) < 0.02
     assert abs(min(mesh.points[:, 2]) + 1.0) < 0.02
 
-    vol = sum(helpers.compute_volumes(mesh.points, mesh.cells["tetra"]))
+    vol = sum(helpers.compute_volumes(mesh.points, mesh.get_cells_type("tetra")))
     assert abs(vol - 4.0 / 3.0 * numpy.pi) < 0.15
-    return
 
 
 if __name__ == "__main__":
